==> remotable-plugins-plugin-0.7.1019.jar: js/iframe-min/plugin-api-min.js <==
(function(j,q){var l=j.AP,f=l._$,e=f.each,v=f.extend,z=f.bind,u=f.trim,r=f.fetch,d=f.debounce,i=f.log,k=f.handleError,a,h,g;
l.Meta={get:function(A){return f("meta[name='ap-"+A+"']").attr("content")
}};
l.localUrl=function(A){return l.Meta.get("local-base-url")+(A==null?"":A)
};
l.BigPipe=function(){function B(){var I,G,F={},C={},M={},D=0;
function H(N){r({url:N+"/"+(D+=1),headers:{Accept:"application/json"},success:function(O){L(O,N)
},error:function(Q,O,P){if(Q.status===404){L({items:[],pending:[]},N)
}else{k(P||(Q&&Q.responseText)||O)
}}})
}function L(O,P){if(O){var N=O.items;
var Q=O.pending;
if(N.length>0||Q.length>0){e(N,function(R,S){E(S)
});
if(Q.length>0){e(F,function(S,R){if(R&&Q.indexOf(S)<0){K(S)
}});
H(P)
}else{K()
}}else{if(!G){K()
}}}}function E(N){var O=N.channelId;
F[O]=true;
if(C[O]){C[O](N)
}else{(M[O]=M[O]||[]).push(N)
}}function K(N){if(N){E({channelId:N,complete:true});
delete C[N];
F[N]=false
}else{if(!G){e(C,K);
G=true
}}}var J={start:function(N){N=N||{};
var P=N.localBaseUrl||l.Meta.get("local-base-url");
var Q=N.requestId;
if(!I&&P&&Q){var O=N.ready||{items:[],pending:[0]};
L(O,P+"/bigpipe/request/"+Q);
I=true
}return J
},subscribe:function(O,N){if(C[O]){throw new Error("Channel '"+O+"' already has a subscriber")
}if(N){C[O]=N;
e(M[O],function(P,Q){E(Q)
});
delete M[O];
if(G){K(O)
}}return J
}};
return J
}var A=B();
A.subscribe("html",function(C){if(!C.complete){f("#"+C.contentId).removeClass("bp-loading").html(C.content);
l.resize()
}});
return v(B,A)
}();
function t(A){var C=v({},A);
var B=A.headers||{};
delete C.headers;
return v(C,{getResponseHeader:function(D){var E=null;
if(D){D=D.toLowerCase();
e(B,function(G,F){if(G.toLowerCase()===D){E=F;
return false
}})
}return E
},getAllResponseHeaders:function(){var D="";
e(B,function(F,E){D+=(D?"\r\n":"")+F+": "+E
});
return D
}})
}function x(A){l.getLocation(function(B){f("head").append({tag:"base",href:B,target:"_parent"})
})
}function o(A){var B=h?"10px 10px 0 10px":"0";
f("head").append({tag:"style",type:"text/css",$text:"body {margin: "+B+" !important;}"})
}function p(A,K){var I=A==null?"100%":A,G=Math.max,E=q.body,J=q.documentElement,H="scrollHeight",C="offsetHeight",B="clientHeight",F=G(J[B],E[H],J[H],E[C],J[C]),D=K==null?F:K;
return{w:I,h:D}
}var n={init:function(B){B=B||{};
if(!g){h=j.location.toString().indexOf("dialog=1")>0;
var A={};
var D={getWorkflowConfiguration:{},setDialogButtonEnabled:{},isDialogButtonEnabled:{}};
e(n,function(E){D[E]={}
});
a=new l._Rpc(A,{remote:D,local:m});
a.init();
if(B.margin!==false){o(B)
}if(B.base===true){x(B)
}if(B.resize!==false){var C=B.resize;
C=C==="auto"?125:+C;
if(C>=0&&C<60){C=60
}if(!h&&C>0){z(j,"load",function(){var E;
setInterval(function(){var F=p();
if(!E||E.w!==F.w||E.h!==F.h){l.resize(F.w,F.h);
E=F
}},C)
})
}else{z(j,"load",function(){l.resize()
})
}}if(h){l.Dialog=w()
}l.WorkflowConfiguration=s();
g=true
}else{i("Manual call to init is a deprecated no-op; use 'data-options' attribute on script to set options")
}},getLocation:function(A){a.getLocation(A)
},getUser:function(A){a.getUser(A)
},getTimeZone:function(A){a.getTimeZone(A)
},fireEvent:function(B,A){a.fireEvent(B,A)
},getWorkflowConfiguration:function(B){var A=decodeURI(RegExp("remoteWorkflowPostFunctionUUID=([0-9a-z-]+)").exec(q.location)[1]);
a.getWorkflowConfiguration(A,B)
},showMessage:function(C,B,A){a.showMessage(C,B,A)
},clearMessage:function(A){a.clearMessage(A)
},resize:d(function(B,A){var C=p(B,A);
a.resize(C.w,C.h)
},50),request:function(E,D){var F,C;
function B(H){return F(H[0],H[1],t(H[2]))
}function A(H){return C(t(H[0]),H[1],H[2])
}function G(){}if(typeof E==="object"){D=E
}else{if(!D){D={url:E}
}else{D.url=E
}}F=D.success||G;
delete D.success;
C=D.error||G;
delete D.error;
a.request(D,B,A)
}};
var m={dialogMessage:function(B){var A=true;
try{if(h){A=l.Dialog.getButton(B).trigger()
}else{k("Received unexpected dialog button event from host:",B)
}}catch(C){k(C)
}return A
},setWorkflowConfigurationMessage:function(){return l.WorkflowConfiguration.trigger()
}};
function w(){var A={};
return{onDialogMessage:function(B,C){this.getButton(B).bind(C)
},getButton:function(B){return{name:B,enable:function(){a.setDialogButtonEnabled(B,true)
},disable:function(){a.setDialogButtonEnabled(B,false)
},toggle:function(){var C=this;
C.isEnabled(function(D){C[D?"disable":"enable"](B)
})
},isEnabled:function(C){a.isDialogButtonEnabled(B,C)
},bind:function(D){var C=A[B];
if(!C){C=A[B]=[]
}C.push(D)
},trigger:function(){var E=this,D=true,C=true,F=A[B];
e(F,function(G,H){C=H.call(E,{button:E,stopPropagation:function(){D=false
}});
return D
});
return !!C
}}
}}
}function s(){var B,A;
return{onSaveValidation:function(C){A=C
},onSave:function(C){B=C
},trigger:function(){if(A.call()){var C=decodeURI(RegExp("remoteWorkflowPostFunctionUUID=([0-9a-z-]+)").exec(q.location)[1]);
return{valid:true,uuid:C,value:""+B.call()}
}else{return{valid:false}
}}}
}v(l,n);
var c,b=f("script[src*='/remotable-plugins/all']");
if(b&&/\/remotable-plugins\/all(-debug)?\.js($|\?)/.test(b.attr("src"))){c={};
var y=b.attr("data-options");
if(y){e(y.split(";"),function(E,D){D=u(D);
if(D){var C=D.split(":"),B=u(C[0]),A=u(C[1]);
if(B&&A!=null){c[B]=A==="true"||A==="false"?A==="true":A
}}})
}}l.init(c)
})(this,document);

==> remotable-plugins-plugin-0.8.1039.jar: js/iframe-min/plugin-api-min.js <==
(function(j,q){var l=j.AP,f=l._$,e=f.each,v=f.extend,z=f.bind,u=f.trim,r=f.fetch,d=f.debounce,i=f.log,k=f.handleError,a,h,g;
l.Meta={get:function(A){return f("meta[name='ap-"+A+"']").attr("content")
}};
l.localUrl=function(A){return l.Meta.get("local-base-url")+(A==null?"":A)
};
l.BigPipe=function(){function B(){var I,G,F={},C={},M={},D=0;
function H(N){r({url:N+"/"+(D+=1),headers:{Accept:"application/json"},success:function(O){L(O,N)
},error:function(Q,O,P){if(Q.status===404){L({items:[],pending:[]},N)
}else{k(P||(Q&&Q.responseText)||O)
}}})
}function L(O,P){if(O){var N=O.items;
var Q=O.pending;
if(N.length>0||Q.length>0){e(N,function(R,S){E(S)
});
if(Q.length>0){e(F,function(S,R){if(R&&f.inArray(S,Q)<0){K(S)
}});
H(P)
}else{K()
}}else{if(!G){K()
}}}}function E(N){var O=N.channelId;
F[O]=true;
if(C[O]){C[O](N)
}else{(M[O]=M[O]||[]).push(N)
}}function K(N){if(N){E({channelId:N,complete:true});
delete C[N];
F[N]=false
}else{if(!G){e(C,K);
G=true
}}}var J={start:function(N){N=N||{};
var P=N.localBaseUrl||l.Meta.get("local-base-url");
var Q=N.requestId;
if(!I&&P&&Q){var O=N.ready||{items:[],pending:[0]};
L(O,P+"/bigpipe/request/"+Q);
I=true
}return J
},subscribe:function(O,N){if(C[O]){throw new Error("Channel '"+O+"' already has a subscriber")
}if(N){C[O]=N;
e(M[O],function(P,Q){E(Q)
});
delete M[O];
if(G){K(O)
}}return J
}};
return J
}var A=B();
A.subscribe("html",function(C){if(!C.complete){f("#"+C.contentId).removeClass("bp-loading").html(C.content);
l.resize()
}});
return v(B,A)
}();
function t(A){var C=v({},A);
var B=A.headers||{};
delete C.headers;
return v(C,{getResponseHeader:function(D){var E=null;
if(D){D=D.toLowerCase();
e(B,function(G,F){if(G.toLowerCase()===D){E=F;
return false
}})
}return E
},getAllResponseHeaders:function(){var D="";
e(B,function(F,E){D+=(D?"\r\n":"")+F+": "+E
});
return D
}})
}function x(A){l.getLocation(function(B){f("head").append({tag:"base",href:B,target:"_parent"})
})
}function o(A){var B=h?"10px 10px 0 10px":"0";
f("head").append({tag:"style",type:"text/css",$text:"body {margin: "+B+" !important;}"})
}function p(A,K){var I=A==null?"100%":A,G=Math.max,E=q.body,J=q.documentElement,H="scrollHeight",C="offsetHeight",B="clientHeight",F=G(J[B],E[H],J[H],E[C],J[C]),D=K==null?F:K;
return{w:I,h:D}
}var n={init:function(B){B=B||{};
if(!g){h=j.location.toString().indexOf("dialog=1")>0;
var A={};
var D={getWorkflowConfiguration:{},setDialogButtonEnabled:{},isDialogButtonEnabled:{}};
e(n,function(E){D[E]={}
});
a=new l._Rpc(A,{remote:D,local:m});
a.init();
if(B.margin!==false){o(B)
}if(B.base===true){x(B)
}if(B.resize!==false){var C=B.resize;
C=C==="auto"?125:+C;
if(C>=0&&C<60){C=60
}if(!h&&C>0){z(j,"load",function(){var E;
setInterval(function(){var F=p();
if(!E||E.w!==F.w||E.h!==F.h){l.resize(F.w,F.h);
E=F
}},C)
})
}else{z(j,"load",function(){l.resize()
})
}}if(h){l.Dialog=w()
}l.WorkflowConfiguration=s();
g=true
}else{i("Manual call to init is a deprecated no-op; use 'data-options' attribute on script to set options")
}},getLocation:function(A){a.getLocation(A)
},getUser:function(A){a.getUser(A)
},getTimeZone:function(A){a.getTimeZone(A)
},fireEvent:function(B,A){a.fireEvent(B,A)
},getWorkflowConfiguration:function(B){var A=decodeURI(RegExp("remoteWorkflowPostFunctionUUID=([0-9a-z-]+)").exec(q.location)[1]);
a.getWorkflowConfiguration(A,B)
},showMessage:function(C,B,A){a.showMessage(C,B,A)
},clearMessage:function(A){a.clearMessage(A)
},resize:d(function(B,A){var C=p(B,A);
a.resize(C.w,C.h)
},50),request:function(E,D){var F,C;
function B(H){return F(H[0],H[1],t(H[2]))
}function A(H){return C(t(H[0]),H[1],H[2])
}function G(){}if(typeof E==="object"){D=E
}else{if(!D){D={url:E}
}else{D.url=E
}}F=D.success||G;
delete D.success;
C=D.error||G;
delete D.error;
a.request(D,B,A)
}};
var m={dialogMessage:function(B){var A=true;
try{if(h){A=l.Dialog.getButton(B).trigger()
}else{k("Received unexpected dialog button event from host:",B)
}}catch(C){k(C)
}return A
},setWorkflowConfigurationMessage:function(){return l.WorkflowConfiguration.trigger()
}};
function w(){var A={};
return{onDialogMessage:function(B,C){this.getButton(B).bind(C)
},getButton:function(B){return{name:B,enable:function(){a.setDialogButtonEnabled(B,true)
},disable:function(){a.setDialogButtonEnabled(B,false)
},toggle:function(){var C=this;
C.isEnabled(function(D){C[D?"disable":"enable"](B)
})
},isEnabled:function(C){a.isDialogButtonEnabled(B,C)
},bind:function(D){var C=A[B];
if(!C){C=A[B]=[]
}C.push(D)
},trigger:function(){var E=this,D=true,C=true,F=A[B];
e(F,function(G,H){C=H.call(E,{button:E,stopPropagation:function(){D=false
}});
return D
});
return !!C
}}
}}
}function s(){var B,A;
return{onSaveValidation:function(C){A=C
},onSave:function(C){B=C
},trigger:function(){if(A.call()){var C=decodeURI(RegExp("remoteWorkflowPostFunctionUUID=([0-9a-z-]+)").exec(q.location)[1]);
return{valid:true,uuid:C,value:""+B.call()}
}else{return{valid:false}
}}}
}v(l,n);
var c,b=f("script[src*='/remotable-plugins/all']");
if(b&&/\/remotable-plugins\/all(-debug)?\.js($|\?)/.test(b.attr("src"))){c={};
var y=b.attr("data-options");
if(y){e(y.split(";"),function(E,D){D=u(D);
if(D){var C=D.split(":"),B=u(C[0]),A=u(C[1]);
if(B&&A!=null){c[B]=A==="true"||A==="false"?A==="true":A
}}})
}}l.init(c)
})(this,document);
